Aglyph 1.1.0 testing summary — Aglyph 3.0.0 documentation

# Aglyph 1.1.0 testing summary

## CPython

Version | Platform
--- | ---
2.5.4 | Windows 7 Ultimate (Windows-7-6.1.7601-SP1)
2.5.6 | Mac OS X 10.6.8 (Darwin-10.8.0-i386-64bit)
2.6.6 | Windows 7 Ultimate (Windows-7-6.1.7601-SP1)
2.6.7 | Mac OS X 10.6.8 (Darwin-10.8.0-i386-64bit)
2.7.2 | Mac OS X 10.6.8 (Darwin-10.8.0-i386-64bit)
| Windows 7 Ultimate (Windows-7-6.1.7601-SP1)
3.0.1 | Windows 7 Ultimate (Windows-7-6.1.7601-SP1)
3.1.4 | Mac OS X 10.6.8 (Darwin-10.8.0-i386-64bit)
| Windows 7 Ultimate (Windows-7-6.1.7601-SP1)
3.2.1 | Mac OS X 10.6.8 (Darwin-10.8.0-i386-64bit)

## PyPy

Version | Platform
--- | ---
1.6 (2.7.1) | Mac OS X 10.6.8 (Darwin-10.8.0-i386-64bit)

## Stackless Python

Version | Platform
--- | ---
2.7.2 | Windows 7 Ultimate (Windows-7-6.1.7601-SP1)
3.2.1 | Windows 7 Ultimate (Windows-7-6.1.7601-SP1)

## IronPython

Version | Platform
--- | ---
2.7 | Windows 7 Ultimate (Windows-7-6.1.7601-SP1; .NET 4.0.30319.237)

## Jython

Version | Platform
--- | ---
2.5.2 | Mac OS X 10.6.8 (Darwin-10.8.0-i386-64bit; 1.6.0_26)
| Windows 7 Ultimate (Windows-7-6.1.7601-SP1; Java 1.6.0_27)